# NuRadioReco

Reconstruction framework for radio detectors of high-energy neutrinos and cosmic-rays

Please see

Glaser, C., Nelles, A., Plaisier, I. et al. Eur. Phys. J. C (2019) 79: 464. https://doi.org/10.1140/epjc/s10052-019-6971-5

for a peer-reviewed description of the contents of NuRadioReco. Please reference this article, if you use NuRadioReco for your analysis.

The code documentation can be found here: https://nu-radio.github.io/NuRadioReco/

For installation instructions and additional documentation/information please see the https://github.com/nu-radio/NuRadioReco/wiki

If you would like to contribute, report or fix a bug, please contact @cg-laser or @anelles for permissions.
We work with pull requests only. They will be reviewed and after review can be merged into the master.

See also CONTRIBUTING.md for contributing guidelines.
